@@ -1,11 +1,12 @@
 from abc import abstractmethod
 
-from api.handler.IKillableScript import IKillableScript
 from api.handler.ILogAbleHandler import ILogAbleHandler
+from api.handler.script.ICacheAbleScript import ICacheAbleScript
+from api.handler.script.IKillableScript import IKillableScript
 from api.model.FdInputPipe import FdInputPipe
 
 
-class ISimpleScriptCE(IKillableScript,ILogAbleHandler):
+class ISimpleScriptCE(IKillableScript,ILogAbleHandler,ICacheAbleScript):
     """
     Python脚本式的CE的基类
     """
