@@ -1,10 +1,11 @@
 from abc import abstractmethod
 
-from api.handler.IKillableScript import IKillableScript
 from api.handler.ILogAbleHandler import ILogAbleHandler
+from api.handler.script.ICacheAbleScript import ICacheAbleScript
+from api.handler.script.IKillableScript import IKillableScript
 
 
-class ISimpleScriptCrawl(IKillableScript,ILogAbleHandler):
+class ISimpleScriptCrawl(IKillableScript,ILogAbleHandler,ICacheAbleScript):
 
     """
     Python脚本式的Crawl的基类
